@@ -1294,7 +1294,7 @@ class Program(hildon.Program):
         self.__log = []
 
 
-    def update_status(self, feed_config, action, item, i, feed_count, percent, j, url_count):
+    def update_status(self, feed_config, action, item, i, feed_count, percent, j, url_count, details):
         if percent:
             feed_config.progress = (j * 100 + percent) / url_count
             self.__model.refresh(feed_config.id)
@@ -1302,6 +1302,8 @@ class Program(hildon.Program):
         if self.__model.show_banner:
             self.set_banner_text(text)
         self.log(text)
+        if details:
+            self.log(details)
 
 
     def update_feed_complete(self, feed_config, new_item_count):
@@ -1328,7 +1330,7 @@ class Program(hildon.Program):
         if item[0]:
             gobject.idle_add(self.update_status, self.__progress_info[0], item[0], item[1],
                 self.__progress_info[1], self.__progress_info[2], item[2],
-                self.__progress_info[3], self.__progress_info[4])
+                self.__progress_info[3], self.__progress_info[4], item[3])
 
 
     def update_feeds(self, feed_configs):
@@ -1354,16 +1356,14 @@ class Program(hildon.Program):
                     for url in urls:
                         feed = None
                         self.__progress_info = (feed_config, i, feed_count, j, url_count)
-                        del_before = None
-                        clear_cache = True
                         try:
+                            clear_cache = True
                             if feed_config.days_to_keep:
-                                del_before = date.today() - timedelta(feed_config.days_to_keep)
                                 clear_cache = False
                             feed = feedcircuit.Feed(url = url, path = self.__model.cache_path, cache_path = ".cache",
                                 title = title, filename = feed_config.get_filename(),
                                 callback = self.callback,
-                                delete_before_date = del_before, always_clear_cache = clear_cache,
+                                days_to_keep = feed_config.days_to_keep, always_clear_cache = clear_cache,
                                 inline_items = feed_config.mode == FeedConfig.mode_inline,
                                 cache_items = feed_config.mode == FeedConfig.mode_cache,
                                 include = feed_config.include, exclude = feed_config.exclude,
